==> stylish-haskell-0.14.5.0-3.1-loong64.pkg.tar.zst: usr/share/haskell/register/stylish-haskell.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
printf '%s' 'name:                 stylish-haskell
version:              0.14.5.0
visibility:           public
id:                   stylish-haskell-0.14.5.0-867ODiQlVl4Iv8SKhke8Gj
key:                  stylish-haskell-0.14.5.0-867ODiQlVl4Iv8SKhke8Gj
license:              BSD-3-Clause
copyright:            2012 Jasper Van der Jeugt
maintainer:           Jasper Van der Jeugt <m@jaspervdj.be>
author:               Jasper Van der Jeugt <m@jaspervdj.be>
homepage:             https://github.com/haskell/stylish-haskell
synopsis:             Haskell code prettifier
description:
    A Haskell code prettifier. For more information, see:

    <https://github.com/haskell/stylish-haskell/blob/master/README.markdown>

category:             Language
abi:                  5c67e1993596af475f51fefc771e5bde
exposed:              True
exposed-modules:
    Language.Haskell.Stylish Language.Haskell.Stylish.Config
    Language.Haskell.Stylish.GHC Language.Haskell.Stylish.Module
    Language.Haskell.Stylish.Parse Language.Haskell.Stylish.Printer
    Language.Haskell.Stylish.Step Language.Haskell.Stylish.Step.Data
    Language.Haskell.Stylish.Step.Imports
    Language.Haskell.Stylish.Step.LanguagePragmas
    Language.Haskell.Stylish.Step.ModuleHeader
    Language.Haskell.Stylish.Step.SimpleAlign
    Language.Haskell.Stylish.Step.Squash
    Language.Haskell.Stylish.Step.Tabs
    Language.Haskell.Stylish.Step.TrailingWhitespace
    Language.Haskell.Stylish.Step.UnicodeSyntax

hidden-modules:
    Language.Haskell.Stylish.Align Language.Haskell.Stylish.Block
    Language.Haskell.Stylish.Comments
    Language.Haskell.Stylish.Config.Cabal
    Language.Haskell.Stylish.Config.Internal
    Language.Haskell.Stylish.Editor Language.Haskell.Stylish.Ordering
    Language.Haskell.Stylish.Util Language.Haskell.Stylish.Verbose
    Paths_stylish_haskell

import-dirs:          /usr/lib/ghc-9.6.6/site-local/stylish-haskell-0.14.5.0
library-dirs:         /usr/lib/ghc-9.6.6/site-local/stylish-haskell-0.14.5.0
library-dirs-static:  /usr/lib/ghc-9.6.6/site-local/stylish-haskell-0.14.5.0
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/stylish-haskell
hs-libraries:         HSstylish-haskell-0.14.5.0-867ODiQlVl4Iv8SKhke8Gj
depends:
    Cabal-3.10.3.0 HsYAML-0.2.1.5-LCvWSQv2Ku5HL4QY5OHlCf
    HsYAML-aeson-0.2.0.2-LF8EqBS47OaA4KQXvZYcZL
    aeson-2.1.2.1-GojnAvr1Jep10WUNi5H1Pi base-4.18.2.1
    bytestring-0.11.5.3 containers-0.6.7 directory-1.3.8.5
    file-embed-0.0.16.0-6A32wX7iXBC7ZTuLWlLLWz filepath-1.4.300.1
    ghc-9.6.6 ghc-boot-9.6.6 ghc-boot-th-9.6.6
    ghc-lib-parser-ex-9.6.0.2-8X52mS6lbEo3Fw3qe9swLM mtl-2.3.1
    regex-tdfa-1.3.2.5-ATqtlBuPETHJOcVIKuiav2
    syb-0.7.3-7GPFF4ffw0kLXaCjDkD2wt text-2.0.2

haddock-interfaces:   /usr/share/doc/stylish-haskell/html/stylish-haskell.haddock
haddock-html:         /usr/share/doc/stylish-haskell/html
' | '/usr/bin/ghc-pkg-9.6.6' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

==> stylish-haskell-0.14.5.0-4-loong64.pkg.tar.zst: usr/share/haskell/register/stylish-haskell.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
printf '%s' 'name:                 stylish-haskell
version:              0.14.5.0
visibility:           public
id:                   stylish-haskell-0.14.5.0-HXcg2D4xlMOF1kSTzoE6BN
key:                  stylish-haskell-0.14.5.0-HXcg2D4xlMOF1kSTzoE6BN
license:              BSD-3-Clause
copyright:            2012 Jasper Van der Jeugt
maintainer:           Jasper Van der Jeugt <m@jaspervdj.be>
author:               Jasper Van der Jeugt <m@jaspervdj.be>
homepage:             https://github.com/haskell/stylish-haskell
synopsis:             Haskell code prettifier
description:
    A Haskell code prettifier. For more information, see:

    <https://github.com/haskell/stylish-haskell/blob/master/README.markdown>

category:             Language
abi:                  b6d4fdcdd9d70e2af621385fb4e5fa84
exposed:              True
exposed-modules:
    Language.Haskell.Stylish Language.Haskell.Stylish.Config
    Language.Haskell.Stylish.GHC Language.Haskell.Stylish.Module
    Language.Haskell.Stylish.Parse Language.Haskell.Stylish.Printer
    Language.Haskell.Stylish.Step Language.Haskell.Stylish.Step.Data
    Language.Haskell.Stylish.Step.Imports
    Language.Haskell.Stylish.Step.LanguagePragmas
    Language.Haskell.Stylish.Step.ModuleHeader
    Language.Haskell.Stylish.Step.SimpleAlign
    Language.Haskell.Stylish.Step.Squash
    Language.Haskell.Stylish.Step.Tabs
    Language.Haskell.Stylish.Step.TrailingWhitespace
    Language.Haskell.Stylish.Step.UnicodeSyntax

hidden-modules:
    Language.Haskell.Stylish.Align Language.Haskell.Stylish.Block
    Language.Haskell.Stylish.Comments
    Language.Haskell.Stylish.Config.Cabal
    Language.Haskell.Stylish.Config.Internal
    Language.Haskell.Stylish.Editor Language.Haskell.Stylish.Ordering
    Language.Haskell.Stylish.Util Language.Haskell.Stylish.Verbose
    Paths_stylish_haskell

import-dirs:          /usr/lib/ghc-9.6.6/site-local/stylish-haskell-0.14.5.0
library-dirs:         /usr/lib/ghc-9.6.6/site-local/stylish-haskell-0.14.5.0
library-dirs-static:  /usr/lib/ghc-9.6.6/site-local/stylish-haskell-0.14.5.0
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/stylish-haskell
hs-libraries:         HSstylish-haskell-0.14.5.0-HXcg2D4xlMOF1kSTzoE6BN
depends:
    Cabal-3.10.3.0 HsYAML-0.2.1.5-5ALdEUiBZBy68ckkwtJ8RG
    HsYAML-aeson-0.2.0.2-4CWU1VzZuSk4saVKtjHz33
    aeson-2.1.2.1-CpIoOLI7lIpJkSqSOmDN9y base-4.18.2.1
    bytestring-0.11.5.3 containers-0.6.7 directory-1.3.8.5
    file-embed-0.0.16.0-6A32wX7iXBC7ZTuLWlLLWz filepath-1.4.300.1
    ghc-9.6.6 ghc-boot-9.6.6 ghc-boot-th-9.6.6
    ghc-lib-parser-ex-9.6.0.2-N3OL9MDf2AGszziPvbcmG mtl-2.3.1
    regex-tdfa-1.3.2.5-EWGvfiHhNcof6jXGuIJ2K
    syb-0.7.3-MvqtDDcT2PHyhdKWhEKAp text-2.0.2

haddock-interfaces:   /usr/share/doc/stylish-haskell/html/stylish-haskell.haddock
haddock-html:         /usr/share/doc/stylish-haskell/html
' | '/usr/bin/ghc-pkg-9.6.6' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"
